Show countries
Show all countries in the database.
Usage
show_countries(rss_table = package_rss)
Arguments
a dataframe with urls and rss feeds in case you
#need to construct your own out of websites not in the included database.
#Be sure to have the same format as the included data. See `R/package_rss.R`
#for details.
Value
a character vector of available countries