Filter URLs in the provided database based on topic, country and language
Source:R/filter_urls.R
filter_urls.RdFilter URLs in the provided database based on topic, country and language
Arguments
- topic
the topic of the feed see
show_topics()for more info.- country
the country of origin of the feed using two capital letters, for example "US". See
show_countries()for more info.- language
the language of the content of the feed using two lowercase letters, for example "en". See
show_languages()for more info.- rss_table
a dataframe with urls and rss feeds in case you need to construct your own out of websites not in the included database. Be sure to have the same format as the included data. See
package_rss.Rfor details.
Examples
filter_urls(topic = "tech", country = "US", language = "en")
#> # A tibble: 29 × 7
#> clean_url language topic_unified main clean_country rss_url GlobalRank
#> <chr> <chr> <chr> <chr> <chr> <chr> <chr>
#> 1 ycombinator.com en tech 1 US https:… 1157
#> 2 wsj.com en tech None US http:/… 83
#> 3 wired.com en tech 1 US http:/… 146
#> 4 washingtonpost… en tech None US http:/… 86
#> 5 usatoday.com en tech None US http:/… 135
#> 6 theverge.com en tech 1 US http:/… 225
#> 7 thenextweb.com en tech None US http:/… 596
#> 8 thehill.com en tech None US http:/… 666
#> 9 techradar.com en tech 1 US http:/… 715
#> 10 reuters.com en tech None US http:/… 81
#> # ℹ 19 more rows